<?php
/**
 * Joinchat CTA Extras
 * Allow insert links, images, video and more in "Joinchat" Call to Action fields.
 *
 * @since             1.0.0
 * @package           JoinChatCTAExtras
 * @author            Creame <hola@crea.me>
 *
 * @wordpress-plugin
 * Plugin Name:       Joinchat CTA Extras
 * Plugin URI:        https://join.chat/en/addons/cta-extras/
 * Description:       Allow insert links, images, video and more in <strong>Joinchat</strong> Call to Action fields.
 * Version:           2.6.3
 * Author:            Creame
 * Author URI:        https://crea.me
 * License:           GPLv3
 * License URI:       http://www.gnu.org/licenses/gpl-3.0.html
 * Requires at least: 4.4.0
 * Tested up to:      6.1
 * Text Domain:       joinchat-cta-extras
 * Domain Path:       /languages
 */

defined( 'WPINC' ) || exit;


add_action( 'plugins_loaded', 'joinchat_cta_extras_load_plugin' );

/**
 * Initialize plugin
 *
 * Load text domain, check dependencies and start admin or public functionalities
 *
 * @since    1.0.0
 * @return   void
 */
function joinchat_cta_extras_load_plugin() {

	$plugin_name    = 'joinchat-cta-extras';
	$plugin_version = '2.6.3';
	$joinchat_min   = '4.1.0';
	$update_key     = '5e9836092e8c3f575051d877';

	if ( is_admin() ) {
		// Load plugin translations (only needed for admin).
		add_action( 'init', 'joinchat_cta_extras_load_textdomain' );

		// Check plugin updates.
		require plugin_dir_path( __FILE__ ) . 'includes/plugin_update_check.php';
		new PluginUpdateChecker_2_0( "https://kernl.us/api/v1/updates/$update_key/", __FILE__, $plugin_name, 24 );
	}

	if ( ! defined( 'JOINCHAT_VERSION' ) ) {

		add_action( 'admin_notices', 'joinchat_cta_extras_joinchat_required' );

	} elseif ( version_compare( JOINCHAT_VERSION, $joinchat_min, '<' ) ) {

		add_action( 'admin_notices', 'joinchat_cta_extras_joinchat_out_of_date' );

	} else {

		if ( is_admin() ) {
			require plugin_dir_path( __FILE__ ) . 'admin/class-joinchat-cta-extras-admin.php';

			new JoinChatCTAExtrasAdmin( $plugin_name, $plugin_version );
		} else {
			require plugin_dir_path( __FILE__ ) . 'public/class-joinchat-cta-extras-public.php';

			new JoinChatCTAExtrasPublic( $plugin_name, $plugin_version );
		}
	}

}

/**
 * Load plugin textdomain
 *
 * @since    2.4.1
 * @return   void
 */
function joinchat_cta_extras_load_textdomain() {
	load_plugin_textdomain( 'joinchat-cta-extras', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
}

/**
 * Joinchat required admin notice
 *
 * @since    1.0.0
 * @return   void
 */
function joinchat_cta_extras_joinchat_required() {
	echo '<div class="error"><p>' .
	__( 'You need to install and activate <strong>Joinchat</strong> in order to use <strong>Joinchat CTA Extras</strong>', 'joinchat-cta-extras' ) .
		'</p></div>';
}

/**
 * Joinchat outdated admin notice
 *
 * @since    1.0.0
 * @return   void
 */
function joinchat_cta_extras_joinchat_out_of_date() {
	if ( ! current_user_can( 'update_plugins' ) ) {
		return;
	}

	$file_path    = 'creame-whatsapp-me/joinchat.php';
	$upgrade_link = wp_nonce_url( self_admin_url( 'update.php?action=upgrade-plugin&plugin=' ) . $file_path, 'upgrade-plugin_' . $file_path );

	echo '<div class="error"><p>' .
		__( '<strong>Joinchat CTA Extras</strong> require a newer version of <strong>Joinchat</strong>.', 'joinchat-cta-extras' ) .
		sprintf( ' <a href="%s">%s</a>', esc_url( $upgrade_link ), esc_html__( 'Update now', 'joinchat-cta-extras' ) ) .
		'</p></div>';
}
